@@ -49,7 +49,6 @@
 
 #include "burn-basics.h"
 #include "burn-debug.h"
-#include "brasero-session-cfg.h"
 #include "brasero-drive-properties.h"
 
 typedef struct _BraseroDrivePropertiesPrivate BraseroDrivePropertiesPrivate;
@@ -64,7 +63,6 @@ struct _BraseroDrivePropertiesPrivate
 	GtkWidget *multi;
 	GtkWidget *burnproof;
 	GtkWidget *notmp;
-	GtkWidget *eject;
 
 	GtkWidget *tmpdir;
 };
@@ -101,23 +99,6 @@ brasero_drive_properties_no_tmp_toggled (GtkToggleButton *button,
 						  BRASERO_BURN_FLAG_NO_TMP_FILES);
 }
 
-static void
-brasero_drive_properties_eject_toggled (GtkToggleButton *button,
-					BraseroDriveProperties *self)
-{
-	BraseroDrivePropertiesPrivate *priv;
-
-	priv = BRASERO_DRIVE_PROPERTIES_PRIVATE (self);
-
-	/* retrieve the flags */
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->eject)))
-		brasero_session_cfg_add_flags (priv->session,
-					       BRASERO_BURN_FLAG_EJECT);
-	else
-		brasero_session_cfg_remove_flags (priv->session,
-						  BRASERO_BURN_FLAG_EJECT);
-}
-
 static void
 brasero_drive_properties_dummy_toggled (GtkToggleButton *button,
 					BraseroDriveProperties *self)
@@ -229,7 +210,7 @@ brasero_drive_properties_check_tmpdir (BraseroDriveProperties *self,
 
 	file = g_file_new_for_commandline_arg (path);
 	if (!file)
-		return FALSE;
+		return TRUE;
 
 	info = g_file_query_info (file,
 				  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
@@ -273,10 +254,10 @@ brasero_drive_properties_check_tmpdir (BraseroDriveProperties *self,
 
 		g_object_unref (info);
 		g_object_unref (file);
-		if (answer == GTK_RESPONSE_OK)
-			return FALSE;
+		if (answer != GTK_RESPONSE_OK)
+			return TRUE;
 
-		return TRUE;
+		return FALSE;
 	}
 
 	if (!g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE)) {
@@ -311,10 +292,10 @@ brasero_drive_properties_check_tmpdir (BraseroDriveProperties *self,
 
 		g_object_unref (info);
 		g_object_unref (file);
-		if (answer == GTK_RESPONSE_OK)
-			return FALSE;
+		if (answer != GTK_RESPONSE_OK)
+			return TRUE;
 
-		return TRUE;
+		return FALSE;
 	}
 
 	g_object_unref (info);
@@ -332,7 +313,7 @@ brasero_drive_properties_check_tmpdir (BraseroDriveProperties *self,
 	 * filesystems have a maximum file size limit of 4 GiB and more than
 	 * often we need a temporary file size of 4 GiB or more. */
 	filesystem = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
-	if (filesystem && !strcmp (filesystem, "msdos")) {
+	if (!g_strcmp0 (filesystem, "msdos")) {
 		gint answer;
 		GtkWidget *dialog;
 		GtkWidget *toplevel;
@@ -362,8 +343,8 @@ brasero_drive_properties_check_tmpdir (BraseroDriveProperties *self,
 		gtk_widget_destroy (dialog);
 
 		g_object_unref (info);
-		if (answer == GTK_RESPONSE_OK)
-			return FALSE;
+		if (answer != GTK_RESPONSE_OK)
+			return TRUE;
 	}
 	else if (info)
 		g_object_unref (info);
@@ -482,12 +463,6 @@ brasero_drive_properties_set_flags (BraseroDriveProperties *self,
 						   flags,
 						   supported,
 						   compulsory);
-	brasero_drive_properties_set_toggle_state (self,
-						   priv->eject,
-						   BRASERO_BURN_FLAG_EJECT,
-						   flags,
-						   supported,
-						   compulsory);						   
 	brasero_drive_properties_set_toggle_state (self,
 						   priv->burnproof,
 						   BRASERO_BURN_FLAG_BURNPROOF,
@@ -757,8 +732,6 @@ brasero_drive_properties_init (BraseroDriveProperties *object)
 	gtk_widget_show (priv->dummy);
 	priv->burnproof = gtk_check_button_new_with_mnemonic (_("Use burn_proof (decrease the risk of failures)"));
 	gtk_widget_show (priv->burnproof);
-	priv->eject = gtk_check_button_new_with_mnemonic (_("_Eject after burning"));
-	gtk_widget_show (priv->eject);
 	priv->notmp = gtk_check_button_new_with_mnemonic (_("Burn the image directly _without saving it to disc"));
 	gtk_widget_show (priv->notmp);
 	priv->multi = gtk_check_button_new_with_mnemonic (_("Leave the disc _open to add other files later"));
@@ -773,10 +746,6 @@ brasero_drive_properties_init (BraseroDriveProperties *object)
 			  "toggled",
 			  G_CALLBACK (brasero_drive_properties_burnproof_toggled),
 			  object);
-	g_signal_connect (priv->eject,
-			  "toggled",
-			  G_CALLBACK (brasero_drive_properties_eject_toggled),
-			  object);
 	g_signal_connect (priv->multi,
 			  "toggled",
 			  G_CALLBACK (brasero_drive_properties_multi_toggled),
@@ -789,7 +758,6 @@ brasero_drive_properties_init (BraseroDriveProperties *object)
 	string = g_strdup_printf ("<b>%s</b>", _("Options"));
 	gtk_box_pack_start (GTK_BOX (vbox),
 			    brasero_utils_pack_properties (string,
-							   priv->eject,
 							   priv->dummy,
 							   priv->burnproof,
 							   priv->multi,
