@@ -33,10 +33,10 @@
 #endif
 
 #include <errno.h>
-#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <fcntl.h>
 
 #include <glib.h>
 #include <glib-object.h>
@@ -91,16 +91,15 @@ struct _BraseroSessionSetting {
 	gchar *label;
 	guint64 rate;
 
-	gchar *tmpdir;
-
 	BraseroBurnFlag flags;
 };
 typedef struct _BraseroSessionSetting BraseroSessionSetting;
 
 struct _BraseroBurnSessionPrivate {
-	FILE *session;
+	int session;
 	gchar *session_path;
 
+	gchar *tmpdir;
 	GSList *tmpfiles;
 
 	BraseroSessionSetting settings [1];
@@ -126,7 +125,6 @@ typedef struct _BraseroBurnSessionPrivate BraseroBurnSessionPrivate;
 
 typedef enum {
 	TAG_CHANGED_SIGNAL,
-	FLAGS_CHANGED_SIGNAL,
 	TRACK_ADDED_SIGNAL,
 	TRACK_REMOVED_SIGNAL,
 	TRACK_CHANGED_SIGNAL,
@@ -135,6 +133,14 @@ typedef enum {
 } BraseroBurnSessionSignalType;
 
 static guint brasero_burn_session_signals [LAST_SIGNAL] = { 0 };
+
+enum {
+	PROP_0,
+	PROP_TMPDIR,
+	PROP_RATE,
+	PROP_FLAGS
+};
+
 static GObjectClass *parent_class = NULL;
 
 static void
@@ -146,9 +152,6 @@ brasero_session_settings_clean (BraseroSessionSetting *settings)
 	if (settings->toc)
 		g_free (settings->toc);
 
-	if (settings->tmpdir)
-		g_free (settings->tmpdir);
-
 	if (settings->label)
 		g_free (settings->label);
 
@@ -170,7 +173,6 @@ brasero_session_settings_copy (BraseroSessionSetting *dest,
 	dest->image = g_strdup (original->image);
 	dest->toc = g_strdup (original->toc);
 	dest->label = g_strdup (original->label);
-	dest->tmpdir = g_strdup (original->tmpdir);
 }
 
 static void
@@ -357,7 +359,7 @@ brasero_burn_session_add_track (BraseroBurnSession *self,
 	}
 
 	/* if there is already a track, then we replace it on condition that it
-	 * has the same type and it's not AUDIO (only one allowed to have many) */
+	 * is not AUDIO (only one type allowed to have several tracks) */
 	if (!BRASERO_IS_TRACK_STREAM (new_track)
 	||  !BRASERO_IS_TRACK_STREAM (priv->tracks->data))
 		brasero_burn_session_free_tracks (self);
@@ -808,6 +810,7 @@ brasero_burn_session_set_rate (BraseroBurnSession *self,
 		return BRASERO_BURN_ERR;
 
 	priv->settings->rate = rate;
+	g_object_notify (G_OBJECT (self), "speed");
 	return BRASERO_BURN_OK;
 }
 
@@ -1190,17 +1193,22 @@ brasero_burn_session_set_tmpdir (BraseroBurnSession *self,
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 
-	if (priv->settings->tmpdir && path
-	&& !strcmp (priv->settings->tmpdir, path))
+	if (!g_strcmp0 (priv->tmpdir, path))
 		return BRASERO_BURN_OK;
 
-	if (priv->settings->tmpdir)
-		g_free (priv->settings->tmpdir);
+	if (!path) {
+		g_free (priv->tmpdir);
+		priv->tmpdir = NULL;
+		g_object_notify (G_OBJECT (self), "tmpdir");
+		return BRASERO_BURN_OK;
+	}
 
-	if (path)
-		priv->settings->tmpdir = g_strdup (path);
-	else
-		priv->settings->tmpdir = NULL;
+	if (!g_str_has_prefix (path, G_DIR_SEPARATOR_S))
+		return BRASERO_BURN_ERR;
+
+	g_free (priv->tmpdir);
+	priv->tmpdir = g_strdup (path);
+	g_object_notify (G_OBJECT (self), "tmpdir");
 
 	return BRASERO_BURN_OK;
 }
@@ -1222,7 +1230,7 @@ brasero_burn_session_get_tmpdir (BraseroBurnSession *self)
 	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), NULL);
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
-	return priv->settings->tmpdir? priv->settings->tmpdir:g_get_tmp_dir ();
+	return priv->tmpdir? priv->tmpdir:g_get_tmp_dir ();
 }
 
 /**
@@ -1254,8 +1262,8 @@ brasero_burn_session_get_tmp_dir (BraseroBurnSession *self,
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 
 	/* create a working directory in tmp */
-	tmpdir = priv->settings->tmpdir ?
-		 priv->settings->tmpdir :
+	tmpdir = priv->tmpdir ?
+		 priv->tmpdir :
 		 g_get_tmp_dir ();
 
 	tmp = g_build_path (G_DIR_SEPARATOR_S,
@@ -1272,13 +1280,13 @@ brasero_burn_session_get_tmp_dir (BraseroBurnSession *self,
 		if (errsv != EACCES)
 			g_set_error (error, 
 				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_GENERAL,
+				     BRASERO_BURN_ERROR_TMP_DIRECTORY,
 				     "%s",
 				     g_strerror (errsv));
 		else
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_PERMISSION,
+				     BRASERO_BURN_ERROR_TMP_DIRECTORY,
 				     _("You do not have the required permission to write at this location"));
 		return BRASERO_BURN_ERR;
 	}
@@ -1326,8 +1334,8 @@ brasero_burn_session_get_tmp_file (BraseroBurnSession *self,
 		return BRASERO_BURN_OK;
 
 	/* takes care of the output file */
-	tmpdir = priv->settings->tmpdir ?
-		 priv->settings->tmpdir :
+	tmpdir = priv->tmpdir ?
+		 priv->tmpdir :
 		 g_get_tmp_dir ();
 
 	name = g_strconcat (BRASERO_BURN_TMP_FILE_NAME, suffix, NULL);
@@ -1347,13 +1355,13 @@ brasero_burn_session_get_tmp_file (BraseroBurnSession *self,
 		if (errsv != EACCES)
 			g_set_error (error, 
 				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_GENERAL,
+				     BRASERO_BURN_ERROR_TMP_DIRECTORY,
 				     "%s",
 				     g_strerror (errsv));
 		else
 			g_set_error (error, 
 				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_PERMISSION,
+				     BRASERO_BURN_ERROR_TMP_DIRECTORY,
 				     _("You do not have the required permission to write at this location"));
 
 		return BRASERO_BURN_ERR;
@@ -1485,9 +1493,7 @@ brasero_burn_session_set_flags (BraseroBurnSession *self,
 		return;
 
 	priv->settings->flags = flags;
-	g_signal_emit (self,
-		       brasero_burn_session_signals [FLAGS_CHANGED_SIGNAL],
-		       0);
+	g_object_notify (G_OBJECT (self), "flags");
 }
 
 /**
@@ -1512,9 +1518,7 @@ brasero_burn_session_add_flag (BraseroBurnSession *self,
 		return;
 
 	priv->settings->flags |= flag;
-	g_signal_emit (self,
-		       brasero_burn_session_signals [FLAGS_CHANGED_SIGNAL],
-		       0);
+	g_object_notify (G_OBJECT (self), "flags");
 }
 
 /**
@@ -1539,9 +1543,7 @@ brasero_burn_session_remove_flag (BraseroBurnSession *self,
 		return;
 
 	priv->settings->flags &= ~flag;
-	g_signal_emit (self,
-		       brasero_burn_session_signals [FLAGS_CHANGED_SIGNAL],
-		       0);
+	g_object_notify (G_OBJECT (self), "flags");
 }
 
 /**
@@ -2131,6 +2133,7 @@ brasero_burn_session_logv (BraseroBurnSession *self,
 			   const gchar *format,
 			   va_list arg_list)
 {
+	int len;
 	gchar *message;
 	gchar *offending;
 	BraseroBurnSessionPrivate *priv;
@@ -2151,12 +2154,13 @@ brasero_burn_session_logv (BraseroBurnSession *self,
 	if (!g_utf8_validate (message, -1, (const gchar**) &offending))
 		*offending = '\0';
 
-	if (fwrite (message, strlen (message), 1, priv->session) != 1)
+	len = strlen (message);
+	if (write (priv->session, message, len) != len)
 		g_warning ("Some log data couldn't be written: %s\n", message);
 
 	g_free (message);
 
-	if (fwrite ("\n", 1, 1, priv->session) != 1)
+	if (write (priv->session, "\n", 1) != 1)
 		g_warning ("Some log data could not be written");
 }
 
@@ -2177,24 +2181,6 @@ brasero_burn_session_log (BraseroBurnSession *self,
 	va_end (args);
 }
 
-void
-brasero_burn_session_set_log_path (BraseroBurnSession *self,
-				   const gchar *session_path)
-{
-	BraseroBurnSessionPrivate *priv;
-
-	g_return_if_fail (BRASERO_IS_BURN_SESSION (self));
-
-	priv = BRASERO_BURN_SESSION_PRIVATE (self);
-	if (priv->session_path) {
-		g_free (priv->session_path);
-		priv->session_path = NULL;
-	}
-
-	if (session_path)
-		priv->session_path = g_strdup (session_path);
-}
-
 const gchar *
 brasero_burn_session_get_log_path (BraseroBurnSession *self)
 {
@@ -2216,28 +2202,31 @@ brasero_burn_session_start (BraseroBurnSession *self)
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 
-	if (!priv->session_path) {
-		int fd;
-		const gchar *tmpdir;
+	/* This must obey the path of the temporary directory if possible */
+	priv->session_path = g_build_path (G_DIR_SEPARATOR_S,
+					   priv->tmpdir,
+					   BRASERO_BURN_TMP_FILE_NAME,
+					   NULL);
+	priv->session = g_mkstemp_full (priv->session_path,
+	                                O_CREAT|O_WRONLY,
+	                                S_IRWXU);
 
-		/* takes care of the output file */
-		tmpdir = priv->settings->tmpdir ?
-			 priv->settings->tmpdir :
-			 g_get_tmp_dir ();
+	if (priv->session < 0) {
+		g_free (priv->session_path);
 
-		/* This must obey the path of the temporary directory */
 		priv->session_path = g_build_path (G_DIR_SEPARATOR_S,
-						   tmpdir,
+						   g_get_tmp_dir (),
 						   BRASERO_BURN_TMP_FILE_NAME,
 						   NULL);
-
-		fd = g_mkstemp (priv->session_path);
-		priv->session = fdopen (fd, "w");
+		priv->session = g_mkstemp_full (priv->session_path,
+		                                O_CREAT|O_WRONLY,
+		                                S_IRWXU);
 	}
-	else
-		priv->session = fopen (priv->session_path, "w");
 
-	if (!priv->session) {
+	if (priv->session < 0) {
+		g_free (priv->session_path);
+		priv->session_path = NULL;
+
 		g_warning ("Impossible to open a session file\n");
 		return FALSE;
 	}
@@ -2312,16 +2301,17 @@ brasero_burn_session_stop (BraseroBurnSession *self)
 	g_return_if_fail (BRASERO_IS_BURN_SESSION (self));
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
-	if (priv->session) {
-		fclose (priv->session);
-		priv->session = NULL;
+	if (priv->session > 0) {
+		close (priv->session);
+		priv->session = -1;
+	}
+
+	if (priv->session_path) {
+		g_free (priv->session_path);
+		priv->session_path = NULL;
 	}
 }
 
-/**
- *
- */
-
 static void
 brasero_burn_session_track_list_free (GSList *list)
 {
@@ -2445,6 +2435,11 @@ brasero_burn_session_finalize (GObject *object)
 		priv->pile_settings = NULL;
 	}
 
+	if (priv->tmpdir) {
+		g_free (priv->tmpdir);
+		priv->tmpdir = NULL;
+	}
+
 	/* clean tmpfiles */
 	for (iter = priv->tmpfiles; iter; iter = iter->next) {
 		gchar *tmpfile;
@@ -2456,9 +2451,9 @@ brasero_burn_session_finalize (GObject *object)
 	}
 	g_slist_free (priv->tmpfiles);
 
-	if (priv->session) {
-		fclose (priv->session);
-		priv->session = NULL;
+	if (priv->session > 0) {
+		close (priv->session);
+		priv->session = -1;
 	}
 
 	if (priv->session_path) {
@@ -2474,7 +2469,75 @@ brasero_burn_session_finalize (GObject *object)
 
 static void
 brasero_burn_session_init (BraseroBurnSession *obj)
-{ }
+{
+	BraseroBurnSessionPrivate *priv;
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (obj);
+	priv->session = -1;
+}
+
+static void
+brasero_burn_session_set_property (GObject *object,
+                                   guint prop_id,
+                                   const GValue *value,
+                                   GParamSpec *pspec)
+{
+	BraseroBurnSessionPrivate *priv;
+
+	g_return_if_fail (BRASERO_IS_BURN_SESSION (object));
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (object);
+
+	switch (prop_id)
+	{
+	case PROP_TMPDIR:
+		brasero_burn_session_set_tmpdir (BRASERO_BURN_SESSION (object),
+		                                 g_value_get_string (value));
+		break;
+	case PROP_RATE:
+		brasero_burn_session_set_rate (BRASERO_BURN_SESSION (object),
+		                               g_value_get_int64 (value));
+		break;
+	case PROP_FLAGS:
+		brasero_burn_session_set_flags (BRASERO_BURN_SESSION (object),
+		                                g_value_get_int (value));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+brasero_burn_session_get_property (GObject *object,
+                                   guint prop_id,
+                                   GValue *value,
+                                   GParamSpec *pspec)
+{
+	BraseroBurnSessionPrivate *priv;
+
+	g_return_if_fail (BRASERO_IS_BURN_SESSION (object));
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (object);
+
+	/* Here we do not call the accessors functions to honour the 0/NULL value
+	 * which means use system default. */
+	switch (prop_id)
+	{
+	case PROP_TMPDIR:
+		g_value_set_string (value, priv->tmpdir);
+		break;
+	case PROP_RATE:
+		g_value_set_int64 (value, priv->settings->rate);
+		break;
+	case PROP_FLAGS:
+		g_value_set_int (value, priv->settings->flags);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
 
 static void
 brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
@@ -2484,7 +2547,10 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 	g_type_class_add_private (klass, sizeof (BraseroBurnSessionPrivate));
 
 	parent_class = g_type_class_peek_parent(klass);
+
 	object_class->finalize = brasero_burn_session_finalize;
+	object_class->set_property = brasero_burn_session_set_property;
+	object_class->get_property = brasero_burn_session_get_property;
 
 	klass->get_output_path = brasero_burn_session_get_output_path_real;
 	klass->get_output_format = brasero_burn_session_get_output_format_real;
@@ -2501,7 +2567,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 	brasero_burn_session_signals [OUTPUT_CHANGED_SIGNAL] =
 	    g_signal_new ("output_changed",
 			  BRASERO_TYPE_BURN_SESSION,
-			  G_SIGNAL_RUN_FIRST,
+			  G_SIGNAL_RUN_LAST,
 			  G_STRUCT_OFFSET (BraseroBurnSessionClass, output_changed),
 			  NULL,
 			  NULL,
@@ -2521,7 +2587,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 	brasero_burn_session_signals [TRACK_ADDED_SIGNAL] =
 	    g_signal_new ("track_added",
 			  BRASERO_TYPE_BURN_SESSION,
-			  G_SIGNAL_RUN_FIRST,
+			  G_SIGNAL_RUN_LAST,
 			  G_STRUCT_OFFSET (BraseroBurnSessionClass, track_added),
 			  NULL,
 			  NULL,
@@ -2542,7 +2608,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 	brasero_burn_session_signals [TRACK_REMOVED_SIGNAL] =
 	    g_signal_new ("track_removed",
 			  BRASERO_TYPE_BURN_SESSION,
-			  G_SIGNAL_RUN_FIRST,
+			  G_SIGNAL_RUN_LAST,
 			  G_STRUCT_OFFSET (BraseroBurnSessionClass, track_removed),
 			  NULL,
 			  NULL,
@@ -2563,7 +2629,7 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 	brasero_burn_session_signals [TRACK_CHANGED_SIGNAL] =
 	    g_signal_new ("track_changed",
 			  BRASERO_TYPE_BURN_SESSION,
-			  G_SIGNAL_RUN_FIRST,
+			  G_SIGNAL_RUN_LAST,
 			  G_STRUCT_OFFSET (BraseroBurnSessionClass, track_changed),
 			  NULL,
 			  NULL,
@@ -2572,24 +2638,6 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 			  1,
 			  BRASERO_TYPE_TRACK);
 
-	/**
- 	* BraseroBurnSession::flags-changed:
- 	* @session: the object which received the signal
-	*
- 	* This signal gets emitted when the flags changed for @session.
- 	*
- 	*/
-	brasero_burn_session_signals [FLAGS_CHANGED_SIGNAL] =
-	    g_signal_new ("flags_changed",
-			  BRASERO_TYPE_BURN_SESSION,
-			  G_SIGNAL_RUN_FIRST,
-			  G_STRUCT_OFFSET (BraseroBurnSessionClass, flags_changed),
-			  NULL,
-			  NULL,
-			  g_cclosure_marshal_VOID__VOID,
-			  G_TYPE_NONE,
-			  0);
-
 	/**
  	* BraseroBurnSession::tag-changed:
  	* @session: the object which received the signal
@@ -2609,6 +2657,32 @@ brasero_burn_session_class_init (BraseroBurnSessionClass *klass)
 			  G_TYPE_NONE,
 			  1,
 	                  G_TYPE_STRING);
+
+	g_object_class_install_property (object_class,
+	                                 PROP_TMPDIR,
+	                                 g_param_spec_string ("tmpdir",
+	                                                      "Temporary directory",
+	                                                      "The path to the temporary directory",
+	                                                      NULL,
+	                                                      G_PARAM_READABLE|G_PARAM_WRITABLE));
+	g_object_class_install_property (object_class,
+	                                 PROP_RATE,
+	                                 g_param_spec_int64 ("speed",
+	                                                     "Burning speed",
+	                                                     "The speed at which a disc should be burned",
+	                                                     0,
+	                                                     G_MAXINT64,
+	                                                     0,
+	                                                     G_PARAM_READABLE|G_PARAM_WRITABLE));
+	g_object_class_install_property (object_class,
+	                                 PROP_FLAGS,
+	                                 g_param_spec_int ("flags",
+	                                                   "Burning flags",
+	                                                   "The flags that will be used to burn",
+	                                                   0,
+	                                                   G_MAXINT,
+	                                                   0,
+	                                                   G_PARAM_READABLE|G_PARAM_WRITABLE));
 }
 
 /**
