@@ -312,13 +312,12 @@ brasero_genisoimage_set_argv_image (BraseroGenisoimage *genisoimage,
 		return result;
 	}
 
-	result = brasero_track_data_get_paths (BRASERO_TRACK_DATA (track),
-					       (image_fs & BRASERO_IMAGE_FS_JOLIET) != 0,
-					       grafts_path,
-					       excluded_path,
-					       emptydir,
-					       videodir,
-					       error);
+	result = brasero_track_data_write_to_paths (BRASERO_TRACK_DATA (track),
+	                                            grafts_path,
+	                                            excluded_path,
+	                                            emptydir,
+	                                            videodir,
+	                                            error);
 	g_free (emptydir);
 
 	if (result != BRASERO_BURN_OK) {
@@ -518,24 +517,20 @@ brasero_genisoimage_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static BraseroBurnResult
-brasero_genisoimage_export_caps (BraseroPlugin *plugin, gchar **error)
+static void
+brasero_genisoimage_export_caps (BraseroPlugin *plugin)
 {
-	BraseroBurnResult result;
 	GSList *output;
 	GSList *input;
 
 	brasero_plugin_define (plugin,
 			       "genisoimage",
-			       _("Use genisoimage to create images from a file selection"),
+	                       NULL,
+	                       /* Translators: image is a disc image here */
+			       _("Creates disc images from a file selection"),
 			       "Philippe Rouquier",
 			       1);
 
-	/* First see if this plugin can be used */
-	result = brasero_process_check_path ("genisoimage", error);
-	if (result != BRASERO_BURN_OK)
-		return result;
-
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_CDR|
 				  BRASERO_MEDIUM_CDRW|
@@ -585,6 +580,15 @@ brasero_genisoimage_export_caps (BraseroPlugin *plugin, gchar **error)
 	g_slist_free (output);
 
 	brasero_plugin_register_group (plugin, _(CDRKIT_DESCRIPTION));
+}
 
-	return BRASERO_BURN_OK;
+G_MODULE_EXPORT void
+brasero_plugin_check_config (BraseroPlugin *plugin)
+{
+	gint version [3] = { 1, 1, 0};
+	brasero_plugin_test_app (plugin,
+	                         "genisoimage",
+	                         "--version",
+	                         "genisoimage %d.%d.%d (Linux)",
+	                         version);
 }
