@@ -620,13 +620,14 @@ brasero_data_disc_image_uri_cb (BraseroTrackDataCfg *vfs,
 	name = brasero_utils_get_uri_name (uri);
 	/* Translators: %s is the name of the image */
 	string = g_strdup_printf (_("There is only one selected file (\"%s\"). It is the image of a disc and its contents can be burned"), name);
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), string);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+											  "%s", string);
 	g_free (string);
 	g_free (name);
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Burn as _File"), GTK_RESPONSE_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Burn as _Data"), GTK_RESPONSE_NO);
 
-	button = brasero_utils_make_button (_("Burn _Contents…"),
+	button = brasero_utils_make_button (_("Burn as _Image"),
 	                                    NULL,
 					    "media-optical-burn",
 					    GTK_ICON_SIZE_BUTTON);
@@ -732,7 +733,6 @@ brasero_data_disc_joliet_rename_cb (BraseroTrackDataCfg *project,
 {
 	BraseroDataDiscPrivate *priv;
 	GtkWidget *dialog;
-	gchar *secondary;
 	gint answer;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
@@ -741,11 +741,10 @@ brasero_data_disc_joliet_rename_cb (BraseroTrackDataCfg *project,
 				     _("Should files be renamed to be fully Windows-compatible?"),
 				     GTK_BUTTONS_NONE,
 				     GTK_MESSAGE_WARNING);
-	secondary = g_strdup_printf ("%s\n%s",
-				     _("Some files don't have a suitable name for a fully Windows-compatible CD."),
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+					 "%s\n%s",
+					 _("Some files don't have a suitable name for a fully Windows-compatible CD."),
 				     _("Those names should be changed and truncated to 64 characters."));
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", secondary);
-	g_free (secondary);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Rename for Full Windows Compatibility"), GTK_RESPONSE_YES);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Disable Full Windows Compatibility"), GTK_RESPONSE_CANCEL);
@@ -789,7 +788,7 @@ brasero_data_disc_name_collision_cb (BraseroTrackDataCfg *project,
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-	                                          _("A file with this name already exists in the folder.  Replacing it will overwrite its content on the disc to be burnt."));
+					 "%s", _("A file with this name already exists in the folder.  Replacing it will overwrite its content on the disc to be burnt."));
 
 	/* Translators: Keep means we're keeping the files that already existed
 	 * in the project.
@@ -844,6 +843,7 @@ brasero_data_disc_2G_file_cb (BraseroTrackDataCfg *project,
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  "%s",
 						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by the ISO9660 standard in its first and second versions (the most widespread ones)."
 						    "\nIt is recommended to use the third version of the ISO9660 standard, which is supported by most operating systems, including Linux and all versions of Windows ©."
 						    "\nHowever, Mac OS X cannot read images created with version 3 of the ISO9660 standard."));
@@ -887,6 +887,7 @@ brasero_data_disc_deep_directory_cb (BraseroTrackDataCfg *project,
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  "%s",
 						  _("The children of this directory will have 7 parent directories."
 						    "\nBrasero can create an image of such a file hierarchy and burn it; but the disc may not be readable on all operating systems."
 						    "\nNote: Such a file hierarchy is known to work on Linux."));
@@ -1198,29 +1199,58 @@ brasero_data_disc_clear (BraseroDisc *disc)
 	brasero_track_data_cfg_reset (priv->project);
 }
 
+static GSList *
+brasero_data_disc_convert_tree_paths_to_references (GtkTreeModel *model,
+                                            	    GList *treepaths)
+{
+	GList *iter;
+	GSList *retval = NULL;
+
+	for (iter = treepaths; iter; iter = iter->next) {
+		GtkTreePath *treepath;
+		GtkTreeRowReference *reference;
+
+		treepath = iter->data;
+		reference = gtk_tree_row_reference_new (model, treepath);
+		retval = g_slist_prepend (retval, reference);
+	}
+
+	return retval;
+}
+
 static void
 brasero_data_disc_delete_selected (BraseroDisc *disc)
 {
 	BraseroDataDiscPrivate *priv;
 	GtkTreeSelection *selection;
 	GtkTreePath *cursorpath;
-	GList *list, *iter;
+	GSList *references;
+	GSList *iter;
+	GList *list;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (disc);
 
 	/* we must start by the end for the treepaths to point to valid rows */
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->tree));
 	list = gtk_tree_selection_get_selected_rows (selection, NULL);
-	list = g_list_reverse (list);
 
 	gtk_tree_view_get_cursor (GTK_TREE_VIEW (priv->tree),
 				  &cursorpath,
 				  NULL);
 
-	for (iter = list; iter; iter = iter->next) {
+	/* Since we are going to modify the model by suppressing the selected
+	 * rows, take a safe approach and convert all tree paths into references */
+	references = brasero_data_disc_convert_tree_paths_to_references (GTK_TREE_MODEL (priv->project), list);
+	g_list_foreach (list, (GFunc) gtk_tree_path_free, NULL);
+	g_list_free (list);
+
+	for (iter = references; iter; iter = iter->next) {
+		GtkTreeRowReference *reference;
 		GtkTreePath *treepath;
 
-		treepath = iter->data;
+		reference = iter->data;
+		treepath = gtk_tree_row_reference_get_path (reference);
+
 		if (cursorpath && !gtk_tree_path_compare (cursorpath, treepath)) {
 			GtkTreePath *tmp_path;
 
@@ -1236,9 +1266,11 @@ brasero_data_disc_delete_selected (BraseroDisc *disc)
 		}
 
 		brasero_track_data_cfg_remove (BRASERO_TRACK_DATA_CFG (priv->project), treepath);
- 		gtk_tree_path_free (treepath);
+
+ 		gtk_tree_row_reference_free (reference);
+		gtk_tree_path_free (treepath);
 	}
-	g_list_free (list);
+	g_slist_free (references);
 
 	if (cursorpath)
 		gtk_tree_path_free (cursorpath);
@@ -2082,7 +2114,12 @@ brasero_data_disc_button_pressed_cb (GtkTreeView *tree,
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
 
-	if (GTK_WIDGET_REALIZED (priv->tree)) {
+	/* Avoid minding signals that happen out of the tree area (like in the 
+	 * headers for example) */
+	if (event->window != gtk_tree_view_get_bin_window (GTK_TREE_VIEW (tree)))
+		return FALSE;
+
+	if (gtk_widget_get_realized (priv->tree)) {
 		result = gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (priv->tree),
 							event->x,
 							event->y,
